#!/bin/bash
# Script to check if everything is fine with systemtap instalation
#
LANG=C; export LANG

show_install_instructions(){
	PACKAGES="$*"
	PACKAGES=$(echo ${PACKAGES} | sed s/' '$//)
	PACKAGES_AND=$(echo $PACKAGES | sed s/' '/' and '/)
	if [ "$DISTRO" == "REDHAT"  -o  "$DISTRO" == "FEDORA" ]; then
		echo "Try running as root: 'yum install ${PACKAGES}'"
	elif [[ $DISTRO == "SUSE" ]]; then
		echo "Try running as root 'zypper install ${PACKAGES}' or installing ${PACKAGES_AND} using yast"
	else
		echo "Try installing ${PACKAGES_AND}"
	fi
}

VERSION=""
if [ -e /etc/redhat-release ]; then
	if [ $(grep -Po "\w+" /etc/redhat-release |head -n 1) == "Fedora" ]; then
	DISTRO="FEDORA"
	VERSION=$(grep -Po "\d+" /etc/redhat-release |head -n 1)
	elif [ $(grep -Po "\w+" /etc/redhat-release |head -n 1)  == "Red" ]; then
	DISTRO="REDHAT"
	VERSION=$(grep -Po "\d+" /etc/redhat-release |head -n 1)
	fi
elif [ -e /etc/SuSE-release ]; then
	DISTRO="SUSE"
	VERSION=$(grep 'VERSION' /etc/SuSE-release|grep -Po "\d+"|head -n 1)
else
	DISTRO="OTHER"
fi

if [ ! -x /usr/bin/stap ]; then
	echo "Systemtap is not installed in your system."
	show_install_instructions "systemtap"
	exit 1
fi

#Getting package information
KERNEL_VERSION=$(uname -r)
KERNEL_PACKAGE=$(rpm -qf "/lib/modules/${KERNEL_VERSION}" | grep -v ^kernel.*-base-.*)
KERNEL_PACKAGE=$(echo $KERNEL_PACKAGE | cut -d ' ' -f 1)
KERNEL_PACKAGE_VERSION=$(echo "$KERNEL_PACKAGE" | grep -oP "\-\d(\d|\.|-)+.*$")
KERNEL_PREFIX=$(echo $KERNEL_PACKAGE | sed s/${KERNEL_PACKAGE_VERSION}//)

if [ "$DISTRO" == "REDHAT"  -o "$DISTRO" == "FEDORA" ]; then
	KERNEL_PACKAGE_VERSION=$(echo $KERNEL_PACKAGE_VERSION | sed s/\.ppc64//)
fi

if [[ "$DISTRO" == "SUSE" && "$VERSION" == "10" ]]; then
	PKGS="debuginfo"
else
	PKGS="debuginfo devel"
fi

MISSING_PKGS=""
for i in $PKGS; do
	PKG=${KERNEL_PREFIX}-${i}${KERNEL_PACKAGE_VERSION}
	if ! rpm -q $PKG > /dev/null; then
		MISSING_PKGS="${MISSING_PKGS}$PKG "
	fi
done

if [[ "$MISSING_PKGS" != "" ]]; then
	echo "There are missing packages."
	show_install_instructions "$MISSING_PKGS"
	exit 2
fi

exit 0
